Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(45)

Unified Diff: tools/clang/scripts/test_tool.py

Issue 2609473002: Renaming blink method names inside gmock's EXPECT_CALL macro invocation. (Closed)
Patch Set: Make SourceFileCallbacks's constructor explicit. Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/clang/scripts/run_tool.py ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/clang/scripts/test_tool.py
diff --git a/tools/clang/scripts/test_tool.py b/tools/clang/scripts/test_tool.py
index ce15db6a969137bf3333df262c1febabdd8235cf..f21e8c3cf7097cb5f2c3d6c01e7122cd125eb825 100755
--- a/tools/clang/scripts/test_tool.py
+++ b/tools/clang/scripts/test_tool.py
@@ -119,12 +119,16 @@ def main(argv):
include_paths = []
include_paths.append(
os.path.realpath(os.path.join(tools_clang_directory, '../..')))
# Many gtest headers expect to have testing/gtest/include in the include
# search path.
include_paths.append(
os.path.realpath(os.path.join(tools_clang_directory,
'../..',
'testing/gtest/include')))
+ include_paths.append(
+ os.path.realpath(os.path.join(tools_clang_directory,
+ '../..',
+ 'testing/gmock/include')))
if len(actual_files) == 0:
print 'Tool "%s" does not have compatible test files.' % tool_to_test
« no previous file with comments | « tools/clang/scripts/run_tool.py ('k') | no next file » | no next file with comments »
@@ -119,12 +119,16 @@ def main(argv):
include_paths.append(
os.path.realpath(os.path.join(tools_clang_directory, '../..')))
- # Many gtest headers expect to have testing/gtest/include in the include
- # search path.
+ # Many gtest and gmock headers expect to have testing/gtest/include and/or
+ # testing/gmock/include in the include search path.
include_paths.append(
os.path.realpath(os.path.join(tools_clang_directory,

Powered by Google App Engine
This is Rietveld 408576698